//parameters

//get the matrix stuff
float4x4 tWVP : WORLDVIEWPROJECTION;
float4x4 tW : WORLD;
float4x4 tVP : VIEWPROJECTION;

float3 camPos : CAMERAPOSITION;

//create a texture input
texture tex;
sampler Samp = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (tex);          //apply a texture to the sampler
    MipFilter = LINEAR;         //sampler states
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

//the tranform of the texture
float4x4 tTex : TEXTUREMATRIX;

//data that flows from VS to the PS
struct vs2ps
{
   float4 pos : POSITION;
   float4 tex : TEXCOORD0;
   float dist : TEXCOORD1;
};

float scale = 1;
float param1 = 1;

//declare your own functions
float4 geomMod (float4 pW)
{
   pW.y = sin(pW.x*param1)*sin(pW.y*param1)*sin(pW.z*param1);
   return pW;
}

float4 geomMod2 (float4 pW)
{
   pW.x = sinh(pW.x*param1)*sin(pW.y*param1)*sin(pW.z*param1);
   return pW;
}

//vertex shader
vs2ps myVS (float4 PosO : POSITION, //get the positions of the mesh
            float4 texCd : TEXCOORD0 //get the texture coords of the mesh
         )
{
     //declare output type
     vs2ps Out;
     
     //put the vertex into world space
     float4 PosW = mul(PosO, tW);

     //modify the geometry (by function call)
     PosW = geomMod2(PosW);

     //calc the distance in world space to the camera
     float dist = distance(camPos, PosW.xyz);

     //fill the output struct
     Out.pos = mul(PosW, tVP);
     Out.tex = mul(texCd, tTex);
     
     //pass the distance value to the PS
     Out.dist = saturate(1-(dist * scale));

     //return the out struct
     return Out;
}

float4 myCol : COLOR;

//pixel shader
float4 myPS (vs2ps In) : COLOR //must return a color
{
    //get the color from the texture
    float4 colFromTexture = tex2D(Samp, In.tex);
    
    //colFromTexture.rgb *= In.dist;
    colFromTexture.rgb = colFromTexture.rgb * In.dist;
    
    //... and return it
    return colFromTexture * myCol;
}

// techniques
technique myTec
{
   pass myPass
   {
        VertexShader = compile vs_1_1 myVS();
        PixelShader = compile ps_1_1 myPS();
   }

}








